==> react-native-hotqa-sdk-0.2.4.tgz: package/src/components/fill-in-the-blank-writing/index.js <==
import React, {useState, useEffect} from 'react';
import {
  StyleSheet,
  View,
  TextInput,
  Text,
  ScrollView,
  Keyboard,
} from 'react-native';
import {hideCotrolAndroid, onConfigurations} from '../../common/helper';
import FontAwesome from 'react-native-vector-icons/FontAwesome';

FontAwesome.loadFont();

export default (props) => {
  const {item, dispatch, isFinish, audio, user_answer} = props;
  const configurations = JSON.parse(item.configurations);
  // const dataCorrect = configurations.data[0];
  const dataQuestion = configurations.paragraph_sections[0];
  const dataSelect = configurations.correct_answer[0];
  // dataSelect.sort();

  const dataSelectNew = [];
  let dataAnswer = [];

  dataSelect.forEach((i) => {
    const newItem = {value: i, answer: ''};
    dataSelectNew.push(newItem);
    dataAnswer.push('');
  });
  // console.log(24, isFinish, user_answer);
  if (isFinish && user_answer.length > 0) {
    user_answer.forEach((answer) => {
      if (item.id === answer.question_id) {
        if (Array.isArray(answer.user_answer.value)) {
          dataAnswer = answer.user_answer.value[0];
        }
      }
    });
  }

  const [data, setData] = useState(dataAnswer);

  useEffect(() => {
    const keyboardDidHideListener = Keyboard.addListener(
      'keyboardDidHide',
      () => {
        hideCotrolAndroid();
      },
    );

    return () => {
      keyboardDidHideListener.remove();
    };
  }, []);

  const setDataAnswer = (answer, index) => {
    audio();
    data[index] = answer;
    onConfigurations(item, data, dispatch);
  };

  const replaceText = (text) => {
    const replace1 = text.replace('*', '').replace('\n', '');
    // const replaceA = _.replace(replace1, new RegExp(' A:', 'g'), '\nA:');
    // const replaceB = _.replace(replaceA, new RegExp(' B:', 'g'), '\nB:');
    return replace1;
  };

  const showAnswer = (correct_answer) => {
    let answer = '';
    correct_answer.forEach((a, i) => {
      if (i === 0) {
        answer = a;
      } else {
        answer = answer + ' / ' + a;
      }
    });
    return answer;
  };

  return (
    <View style={[styles.configView]}>
      <ScrollView contentContainerStyle={styles.containerScroll}>
        {dataQuestion.map((question, index) => {
          // console.log(51, item);
          return (
            <View style={styles.containerQues} key={index}>
              <Text style={styles.txtContent}>{replaceText(question)}</Text>
              {question.includes('(') && (
                <TextInput
                  editable={isFinish ? false : true}
                  underlineColorAndroid="transparent"
                  style={styles.textInput}
                  returnKeyType="done"
                  autoCapitalize="none"
                  onChangeText={(text) => setDataAnswer(text, index)}
                  value={data[index]}
                />
              )}
            </View>
          );
        })}
      </ScrollView>
      {isFinish && (
        <Text style={[styles.txtAnswer, {marginTop: 100, marginBottom: 10}]}>
          Đáp án
        </Text>
      )}
      {isFinish && (
        <ScrollView>
          {dataSelect.map((answer, index) => {
            return (
              <Text style={[styles.txtAnswer]} key={index}>
                {`(${index + 1}) ` + showAnswer(answer)}
              </Text>
            );
          })}
        </ScrollView>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flexWrap: 'wrap',
    // width: '100%',
    // minHeight: 200,
    marginEnd: 20,
    alignItems: 'center',
  },
  containerScroll: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  containerQues: {
    flexDirection: 'row',
    marginVertical: 5,
    flexWrap: 'wrap',
    alignItems: 'center',
  },
  textInput: {
    color: 'black',
    fontSize: 16,
    textAlign: 'center',
    minWidth: 80,
    paddingVertical: 6,
    borderColor: '#F5A237',
    borderRadius: 12,
    borderWidth: 1,
    marginHorizontal: 5,
    paddingHorizontal: 8,
    // backgroundColor: '#D7E9FF',
  },
  viewTextType2: {
    minWidth: 80,
    fontSize: 14,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    color: 'red',
    textAlign: 'center',
  },
  viewBorder: {
    minWidth: 80,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    alignItems: 'center',
  },
  viewDropdown: {
    marginHorizontal: 8,
    borderColor: '#F5A237',
    borderWidth: 1,
    paddingHorizontal: 8,
    borderRadius: 20,
    justifyContent: 'center',
  },
  contentStyle: {
    height: 30,
    minWidth: 80,
    paddingTop: 2,
  },
  text: {
    textAlign: 'center',
    color: 'black',
    fontSize: 16,
    marginTop: 2,
  },
  txtContent: {
    fontSize: 16,
    lineHeight: 24,
  },
  txtAnswer: {
    color: 'red',
    fontSize: 18,
    marginTop: 4,
    lineHeight: 28,
  },
});

==> react-native-hotqa-sdk-0.2.7.tgz: package/src/components/fill-in-the-blank-writing/index.js <==
import React, {useState, useEffect} from 'react';
import {
  StyleSheet,
  View,
  TextInput,
  Text,
  ScrollView,
  Keyboard,
} from 'react-native';
import {hideCotrolAndroid, onConfigurations} from '../../common/helper';
import FontAwesome from 'react-native-vector-icons/FontAwesome';

FontAwesome.loadFont();

export default (props) => {
  const {item, dispatch, isFinish, audio, user_answer} = props;
  const configurations = JSON.parse(item.configurations);
  // const dataCorrect = configurations.data[0];
  const dataQuestion = configurations.paragraph_sections;
  const dataSelect = configurations.correct_answer;
  // dataSelect.sort();

  // const dataSelectNew = [];
  let dataAnswer = [];

  dataSelect.forEach((i) => {
    const newItem = [''];
    // dataSelectNew.push(newItem);
    dataAnswer.push(newItem);
  });
  // console.log(24, isFinish, user_answer);
  if (isFinish && user_answer.length > 0) {
    user_answer.forEach((answer) => {
      if (item.id === answer.question_id) {
        if (Array.isArray(answer.user_answer.value)) {
          dataAnswer = answer.user_answer.value;
        }
      }
    });
  }
  // console.log(111, 'tienvt', dataAnswer);
  const [data] = useState(dataAnswer);

  useEffect(() => {
    const keyboardDidHideListener = Keyboard.addListener(
      'keyboardDidHide',
      () => {
        hideCotrolAndroid();
      },
    );

    return () => {
      keyboardDidHideListener.remove();
    };
  }, []);

  const setDataAnswer = (answer, index, ind) => {
    audio();

    data.forEach((_, i) => {
      data[i] = [answer];
    });
    // data[index][ind] = answer
    onConfigurations(item, data, dispatch);
  };

  const replaceText = (text) => {
    if (text.startsWith('B:') || text.startsWith('C:')) {
      text = '     ' + text;
    }
    return text;
  };

  const showAnswer = (correct_answer) => {
    let answer = '';
    correct_answer.forEach((a, i) => {
      if (i === 0) {
        answer = a;
      } else {
        answer = answer + ' / ' + a;
      }
    });
    return answer;
  };

  return (
    <View style={[styles.configView]}>
      <ScrollView contentContainerStyle={styles.containerScroll}>
        {dataQuestion.map((questions, index) =>
          questions.map((question, ind) => {
            return (
              <View
                style={[
                  styles.containerQues,
                  !question.includes('(') && {marginVertical: 5},
                ]}
                key={`${index}-${ind}`}>
                <Text style={styles.txtContent}>{replaceText(question)}</Text>
                {question.includes('(') && (
                  <TextInput
                    editable={isFinish ? false : true}
                    underlineColorAndroid="transparent"
                    style={styles.textInput}
                    returnKeyType="done"
                    autoCapitalize="none"
                    onChangeText={(text) => setDataAnswer(text, index, ind)}
                    value={data[index][ind]}
                  />
                )}
              </View>
            );
          }),
        )}
      </ScrollView>
      {isFinish && (
        <Text style={[styles.txtAnswer, {marginTop: 100, marginBottom: 10}]}>
          Đáp án
        </Text>
      )}
      {isFinish && (
        <ScrollView>
          <Text style={[styles.txtAnswer]}>{dataSelect[0]}</Text>
          {/* {dataSelect.map((answer, index) => {
            return (
              <Text style={[styles.txtAnswer]} key={index}>
                {`(${index + 1}) ` + showAnswer(answer)}
              </Text>
            );
          })} */}
        </ScrollView>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flexWrap: 'wrap',
    // width: '100%',
    // minHeight: 200,
    marginEnd: 20,
    alignItems: 'center',
  },
  containerScroll: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  containerQues: {
    flexDirection: 'row',
    // marginVertical: 5,
    flexWrap: 'wrap',
    alignItems: 'center',
  },
  textInput: {
    color: 'black',
    fontSize: 16,
    textAlign: 'center',
    minWidth: 80,
    paddingVertical: 6,
    borderColor: '#F5A237',
    borderRadius: 12,
    borderWidth: 1,
    marginHorizontal: 5,
    paddingHorizontal: 8,
    // backgroundColor: '#D7E9FF',
  },
  viewTextType2: {
    minWidth: 80,
    fontSize: 14,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    color: 'red',
    textAlign: 'center',
  },
  viewBorder: {
    minWidth: 80,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    alignItems: 'center',
  },
  viewDropdown: {
    marginHorizontal: 8,
    borderColor: '#F5A237',
    borderWidth: 1,
    paddingHorizontal: 8,
    borderRadius: 20,
    justifyContent: 'center',
  },
  contentStyle: {
    height: 30,
    minWidth: 80,
    paddingTop: 2,
  },
  text: {
    textAlign: 'center',
    color: 'black',
    fontSize: 16,
    marginTop: 2,
  },
  txtContent: {
    fontSize: 16,
    lineHeight: 24,
  },
  txtAnswer: {
    color: 'red',
    fontSize: 18,
    marginTop: 4,
    lineHeight: 28,
  },
});
